@@ -1,5 +1,5 @@
 unless Regexp.respond_to? :try_convert
-  require 'backports/tools'
+  require 'backports/tools/arguments'
 
   def Regexp.try_convert(obj)
     Backports.try_convert(obj, Regexp, :to_regexp)
